# -*- coding: utf-8 -*-

import requests
import urllib

from django.urls import reverse


class RemoteTestMixin:
    # OFFICE -
    def v1__office_office_list(self, filters=None):
        self.token_refresh()
        headers = {'Authorization': 'JWT {}'.format(self.jwt)}
        endpoint = reverse(
            'api-v1-office:office-list',
            args=('',)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.get(url, headers=headers, params=filters)
        self.rprint(resp)
        return resp

    def v1__office_office_retrieve(self, pk):
        self.token_refresh()
        headers = {'Authorization': 'JWT {}'.format(self.jwt)}
        endpoint = reverse(
            'api-v1-office:office-detail',
            args=('', pk,)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.get(url, headers=headers)
        self.rprint(resp)
        return resp

    def v1__office_office_create(self, post_dict):
        self.token_refresh()
        headers = {'Authorization': 'JWT {}'.format(self.jwt)}
        endpoint = reverse(
            'api-v1-office:office-list',
            args=('',)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.post(url, headers=headers, json=post_dict)
        self.rprint(resp)
        return resp

    def v1__office_office_update(self, pk, post_dict):
        self.token_refresh()
        headers = {'Authorization': 'JWT {}'.format(self.jwt)}
        endpoint = reverse(
            'api-v1-office:office-detail',
            args=('', pk,)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.patch(url, headers=headers, json=post_dict)
        self.rprint(resp)
        return resp

    def v1__office_office_enable(self, pk):
        self.token_refresh()
        headers = {'Authorization': 'JWT {}'.format(self.jwt)}
        endpoint = reverse(
            'api-v1-office:office-enable',
            args=('', pk,)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        post_dict = {}
        resp = requests.patch(url, headers=headers, json=post_dict)
        self.rprint(resp)
        return resp

    def v1__office_office_disable(self, pk):
        self.token_refresh()
        headers = {'Authorization': 'JWT {}'.format(self.jwt)}
        endpoint = reverse(
            'api-v1-office:office-disable',
            args=('', pk,)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        post_dict = {}
        resp = requests.patch(url, headers=headers, json=post_dict)
        self.rprint(resp)
        return resp

    def v1__office_office_destroy(self, pk):
        self.token_refresh()
        headers = {'Authorization': 'JWT {}'.format(self.jwt)}
        endpoint = reverse(
            'api-v1-office:office-detail',
            args=('', pk,)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.delete(url, headers=headers)
        self.rprint(resp)
        return resp

    # AREA -

    def v1__office_area_list(self, filters=None):
        self.token_refresh()
        headers = {'Authorization': 'JWT {}'.format(self.jwt)}
        endpoint = reverse(
            'api-v1-office:area-list',
            args=('',)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.get(url, headers=headers, params=filters)
        self.rprint(resp)
        return resp

    def v1__office_area_retrieve(self, pk):
        self.token_refresh()
        headers = {'Authorization': 'JWT {}'.format(self.jwt)}
        endpoint = reverse(
            'api-v1-office:area-detail',
            args=('', pk,)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.get(url, headers=headers)
        self.rprint(resp)
        return resp

    def v1__office_area_create(self, post_dict):
        self.token_refresh()
        headers = {'Authorization': 'JWT {}'.format(self.jwt)}
        endpoint = reverse(
            'api-v1-office:area-list',
            args=('',)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.post(url, headers=headers, json=post_dict)
        self.rprint(resp)
        return resp

    def v1__office_area_update(self, pk, post_dict):
        self.token_refresh()
        headers = {'Authorization': 'JWT {}'.format(self.jwt)}
        endpoint = reverse(
            'api-v1-office:area-detail',
            args=('', pk,)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.patch(url, headers=headers, json=post_dict)
        self.rprint(resp)
        return resp

    def v1__office_area_enable(self, pk):
        self.token_refresh()
        headers = {'Authorization': 'JWT {}'.format(self.jwt)}
        endpoint = reverse(
            'api-v1-office:area-enable',
            args=('', pk,)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        post_dict = {}
        resp = requests.patch(url, headers=headers, json=post_dict)
        self.rprint(resp)
        return resp

    def v1__office_area_disable(self, pk):
        self.token_refresh()
        headers = {'Authorization': 'JWT {}'.format(self.jwt)}
        endpoint = reverse(
            'api-v1-office:area-disable',
            args=('', pk,)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        post_dict = {}
        resp = requests.patch(url, headers=headers, json=post_dict)
        self.rprint(resp)
        return resp

    def v1__office_area_destroy(self, pk):
        self.token_refresh()
        headers = {'Authorization': 'JWT {}'.format(self.jwt)}
        endpoint = reverse(
            'api-v1-office:area-detail',
            args=('', pk,)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.delete(url, headers=headers)
        self.rprint(resp)
        return resp
